@@ -20,7 +20,7 @@ pub use user_dirs::UserDirs;
 
 #[cfg(not(windows))]
 pub(crate) fn not_found() -> io::Error {
-    posish::io::Errno::NOENT.io_error()
+    posish::io::Error::NOENT.into()
 }
 
 #[cfg(windows)]
